@@ -2,7 +2,7 @@ import base64
 import locale
 import io
 
-from typing import BinaryIO, List, Tuple, Union
+from typing import List, Tuple, Union
 from uuid import uuid4
 from zipfile import ZIP_DEFLATED, ZipFile
 from aiohttp import ClientSession, ClientTimeout
@@ -45,6 +45,8 @@ class Client(AminoHttpClient):
         self._websocket: WebSocketClient = WebSocketClient(self.auth, self._loop)
         self.callbacks_to_execute: list = []
 
+        self.edit_chat
+
     async def __aenter__(self) -> 'Client':
         return self
 
@@ -117,8 +119,7 @@ class Client(AminoHttpClient):
             "clientType": 100,
             "secret": f"0 {password}",
             "deviceID": self.deviceId,
-            "action": "normal",
-            "timestamp": int(time() * 1000)
+            "action": "normal"
         }
 
         response = await self.post("/g/s/auth/login", data)
@@ -138,8 +139,7 @@ class Client(AminoHttpClient):
     async def logout(self):
         data = {
             "deviceID": self.deviceId,
-            "clientType": 100,
-            "timestamp": int(time() * 1000)
+            "clientType": 100
         }
 
         response = await self.post(f"/g/s/auth/logout", data)
@@ -184,8 +184,7 @@ class Client(AminoHttpClient):
             "longitude": 0,
             "address": None,
             "type": 1,
-            "identity": email,
-            "timestamp": int(time() * 1000)
+            "identity": email
         }
 
         if code:
@@ -204,8 +203,7 @@ class Client(AminoHttpClient):
         data = {
             "secret": f"0 {password}",
             "deviceID": self.deviceId,
-            "email": email,
-            "timestamp": int(time() * 1000)
+            "email": email
         }
 
         response = await self.post(f"/g/s/account/delete-request/cancel", data)
@@ -217,8 +215,7 @@ class Client(AminoHttpClient):
 
         data = {
             "age": age,
-            "gender": genderType,
-            "timestamp": int(time() * 1000)
+            "gender": genderType
         }
 
         response = await self.post(f"/g/s/persona/profile/basic", data)
@@ -230,8 +227,7 @@ class Client(AminoHttpClient):
                 "type": 1,
                 "identity": email,
                 "data": {"code": code}},
-            "deviceID": self.deviceId,
-            "timestamp": int(time() * 1000)
+            "deviceID": self.deviceId
         }
 
         response = await self.post(f"/g/s/auth/check-security-validation", data)
@@ -298,8 +294,7 @@ class Client(AminoHttpClient):
             "clientType": 100,
             "timezone": -timezone // 1000,
             "systemPushEnabled": True,
-            "locale": locale()[0],
-            "timestamp": int(time() * 1000)
+            "locale": locale()[0]
         }
 
         response = await self.post(f"/g/s/device", data)
@@ -310,7 +305,7 @@ class Client(AminoHttpClient):
         return (await response.json())["mediaValue"]
     
     async def upload_bubble_thumbnail(self, image: bytes) -> str:
-        response = await self.post(f"{self.api}/g/s/media/upload/target/chat-bubble-thumbnail", None, image, "image/png")
+        response = await self.post(f"/g/s/media/upload/target/chat-bubble-thumbnail", None, image, "image/png")
         return (await response.json())["mediaValue"]
     
     async def get_eventlog(self, language: str = "en") -> dict:
@@ -350,8 +345,7 @@ class Client(AminoHttpClient):
             "title": title,
             "inviteeUids": userId if isinstance(userId, list) else [userId],
             "initialMessageContent": message,
-            "content": content,
-            "timestamp": int(time() * 1000)
+            "content": content
         }
 
         if isGlobal: 
@@ -376,8 +370,7 @@ class Client(AminoHttpClient):
 
     async def invite_to_chat(self, userId: Union[str, list], chatId: str) -> int:
         data = {
-            "uids":  userId if isinstance(userId, list) else [userId],
-            "timestamp": int(time() * 1000)
+            "uids":  userId if isinstance(userId, list) else [userId]
         }
 
         response = await self.post(f"/g/s/chat/thread/{chatId}/member/invite", data)
@@ -444,7 +437,7 @@ class Client(AminoHttpClient):
     
     async def send_message(self, chatId: str, message: str = None, type: int = 0, replyTo: str = None, 
             mentions: list = None, embedId: str = None, embedType: int = None, embedLink: str = None, 
-            embedTitle: str = None, embedContent: str = None, embedImage: Union[BinaryIO, str] = None) -> Message:
+            embedTitle: str = None, embedContent: str = None, embedImage: Union[bytes, str] = None) -> Message:
 
         message = message.replace("<$", "‎‏")
         message = message.replace("$>", "‬‭")
@@ -453,7 +446,7 @@ class Client(AminoHttpClient):
         if embedImage:
             if isinstance(embedImage, str):
                 embedImage = [[100, embedImage, None]]
-            elif isinstance(embedImage, BinaryIO):
+            elif isinstance(embedImage, bytes):
                 embedImage = [[100, await self.upload_media(embedImage, "image"), None]]
             else:
                 raise SpecifyType()
@@ -470,8 +463,7 @@ class Client(AminoHttpClient):
                 "content": embedContent, # Embed message
                 "mediaList": embedImage  # ObjectPreview
             },
-            "extensions": {"mentionedArray": mentions},
-            "timestamp": int(time() * 1000)
+            "extensions": {"mentionedArray": mentions}
         }
 
         if replyTo:
@@ -481,31 +473,29 @@ class Client(AminoHttpClient):
         return Message(**(await response.json())["message"])
     
     
-    async def send_image(self, chatId: str, file: BinaryIO) -> Message:
+    async def send_image(self, chatId: str, file: bytes) -> Message:
         data = {
             "type": 0,
             "mediaType": 100,
             "mediaUhqEnabled": True,
-            "clientRefId": int(time() / 10 % 1000000000),
-            "timestamp": int(time() * 1000)
+            "clientRefId": int(time() / 10 % 1000000000)
         }
 
         data["mediaUploadValueContentType"] = FileTypes.IMAGE
-        data["mediaUploadValue"] = base64.b64encode(file.read()).decode()
+        data["mediaUploadValue"] = base64.b64encode(file).decode()
 
         response = await self.post(f"/g/s/chat/thread/{chatId}/message", data)
         return Message(**(await response.json())["message"])
     
-    async def send_audio(self, chatId: str, file: BinaryIO) -> Message:
+    async def send_audio(self, chatId: str, file: bytes) -> Message:
         data = {
             "type": 2,
             "mediaType": 110,
-            "clientRefId": int(time() / 10 % 1000000000),
-            "timestamp": int(time() * 1000)
+            "clientRefId": int(time() / 10 % 1000000000)
         }
 
         data["mediaUploadValueContentType"] = FileTypes.AUDIO
-        data["mediaUploadValue"] = base64.b64encode(file.read()).decode()
+        data["mediaUploadValue"] = base64.b64encode(file).decode()
 
         response = await self.post(f"/g/s/chat/thread/{chatId}/message", data)
         return Message(**(await response.json())["message"])
@@ -514,8 +504,7 @@ class Client(AminoHttpClient):
         data = {
             "type": 3,
             "stickerId": stickerId,
-            "clientRefId": int(time() / 10 % 1000000000),
-            "timestamp": int(time() * 1000)
+            "clientRefId": int(time() / 10 % 1000000000)
         }
 
         response = await self.post(f"/g/s/chat/thread/{chatId}/message", data)
@@ -524,8 +513,7 @@ class Client(AminoHttpClient):
     async def delete_message(self, chatId: str, messageId: str, asStaff: bool = False, reason: str = None) -> int:
         data = {
             "adminOpName": 102,
-            "adminOpNote": {"content": reason},
-            "timestamp": int(time() * 1000)
+            "adminOpNote": {"content": reason}
         }
 
         if not asStaff:
@@ -537,23 +525,44 @@ class Client(AminoHttpClient):
 
     async def mark_as_read(self, chatId: str, messageId: str) -> int:
         data = {
-            "messageId": messageId,
-            "timestamp": int(time() * 1000)
+            "messageId": messageId
         }
 
         response = await self.post(f"/g/s/chat/thread/{chatId}/mark-as-read", data)
         return response.status
     
     async def edit_chat(self, chatId: str, doNotDisturb: bool = None, pinChat: bool = None, 
-            title: str = None, icon: str = None, backgroundImage: BinaryIO = None, content: str = None, 
+            title: str = None, icon: Union[bytes, str] = None, backgroundImage: Union[bytes, str] = None, content: str = None, 
             announcement: str = None, coHosts: list = None, keywords: list = None, pinAnnouncement: bool = None, 
             publishToGlobal: bool = None, canTip: bool = None, viewOnly: bool = None, canInvite: bool = None, fansOnly: bool = None) -> int:
-        data = {"timestamp": int(time() * 1000)}
+        data = {}
         responses = []
 
         if title: data["title"] = title
         if content: data["content"] = content
-        if icon: data["icon"] = icon
+
+        if icon:
+            if isinstance(icon, str):
+                data["icon"] = icon
+
+            elif isinstance(icon, bytes):
+                data["icon"] = await self.upload_media(icon)
+            
+            else: raise SpecifyType()
+        
+        if backgroundImage:
+            if isinstance(backgroundImage, str):
+                data = {"media": [100, backgroundImage, None]}
+                response = await self.post(f"/g/s/chat/thread/{chatId}/member/{self.userId}/background", data)
+                responses.append(response.status)
+
+            elif isinstance(backgroundImage, bytes):
+                data = {"media": [100, await self.upload_media(backgroundImage, "image"), None]}
+                response = await self.post(f"/g/s/chat/thread/{chatId}/member/{self.userId}/background", data)
+                responses.append(response.status)
+            
+            else: raise SpecifyType()
+
         if keywords: data["keywords"] = keywords
         if announcement: data["extensions"] = {"announcement": announcement}
         if pinAnnouncement: data["extensions"] = {"pinAnnouncement": pinAnnouncement}
@@ -563,24 +572,21 @@ class Client(AminoHttpClient):
         if not publishToGlobal: data["publishToGlobal"] = 1
 
         if coHosts:
-            data = {"uidList": coHosts, "timestamp": int(time() * 1000)}
+            data = {"uidList": coHosts}
             response = await self.post(f"/g/s/chat/thread/{chatId}/co-host", data)
             responses.append(response.status)
 
         if doNotDisturb is True:
-            data = {"alertOption": 2, "timestamp": int(time() * 1000)}
+            data = {"alertOption": 2}
             response = await self.post(f"/g/s/chat/thread/{chatId}/member/{self.userId}/alert", data)
             responses.append(response.status)
 
         if doNotDisturb is False:
-            data = {"alertOption": 1, "timestamp": int(time() * 1000)}
+            data = {"alertOption": 1}
             response = await self.post(f"/g/s/chat/thread/{chatId}/member/{self.userId}/alert", data)
             responses.append(response.status)
 
-        if backgroundImage:
-            data = {"media": [100, await self.upload_media(backgroundImage, "image"), None], "timestamp": int(time() * 1000)}
-            response = await self.post(f"/g/s/chat/thread/{chatId}/member/{self.userId}/background", data)
-            responses.append(response.status)
+        
         
         if pinChat is True: responses.append((await self.post(f"/g/s/chat/thread/{chatId}/pin", data)).status)
         if pinChat is False: responses.append((await self.post(f"/g/s/chat/thread/{chatId}/unpin", data)).status)
@@ -603,8 +609,7 @@ class Client(AminoHttpClient):
             "coins": coins,
             "tippingContext": {
                 "transactionId": transactionId or str(uuid4())
-            },
-            "timestamp": int(time() * 1000)
+            }
         }
 
         if blogId:
@@ -629,7 +634,7 @@ class Client(AminoHttpClient):
             return response.status
 
         elif isinstance(userId, list):
-            data = {"targetUidList": userId, "timestamp": int(time() * 1000)}
+            data = {"targetUidList": userId}
             response = await self.post(f"/g/s/user-profile/{self.userId}/joined", data)
             return response.status
 
@@ -654,8 +659,7 @@ class Client(AminoHttpClient):
 
         data = {
             "flagType": flagType,
-            "message": reason,
-            "timestamp": int(time() * 1000)
+            "message": reason
         }
 
         if userId:
@@ -690,7 +694,7 @@ class Client(AminoHttpClient):
         return response.json()
     
     async def join_community(self, comId: str, invitationCode: str = None) -> int:
-        data = {"timestamp": int(time() * 1000)}
+        data = {}
         if invitationCode: data["invitationId"] = await self.link_identify(invitationCode)
 
         response = await self.post(f"/x{comId}/s/community/join", data)
@@ -698,8 +702,7 @@ class Client(AminoHttpClient):
 
     async def request_join_community(self, comId: str, message: str = None) -> int:
         data = {
-            "message": message, 
-            "timestamp": int(time() * 1000)
+            "message": message
         }
 
         response = await self.post(f"/x{comId}/s/community/membership-request", data)
@@ -709,15 +712,14 @@ class Client(AminoHttpClient):
         response = await self.post(f"/x{comId}/s/community/leave")
         return response.status
 
-    async def edit_profile(self, nickname: str = None, content: str = None, icon: Union[str, BinaryIO] = None,
-            backgroundColor: str = None, backgroundImage: Union[str, BinaryIO] = None, defaultBubbleId: str = None) -> int:
+    async def edit_profile(self, nickname: str = None, content: str = None, icon: Union[str, bytes] = None,
+            backgroundColor: str = None, backgroundImage: Union[str, bytes] = None, defaultBubbleId: str = None) -> int:
         data = {
             "address": None,
             "latitude": 0,
             "longitude": 0,
             "mediaList": None,
-            "eventSource": SourceTypes.USER_PROFILE,
-            "timestamp": int(time() * 1000)
+            "eventSource": SourceTypes.USER_PROFILE
         }
 
         if content: data["content"] = content
@@ -729,7 +731,7 @@ class Client(AminoHttpClient):
             if isinstance(icon, str):
                 data["icon"] = icon
 
-            if isinstance(icon, BinaryIO):
+            if isinstance(icon, bytes):
                 data["icon"] = await self.upload_media(icon, "image")
 
             else: raise SpecifyType()
@@ -739,7 +741,7 @@ class Client(AminoHttpClient):
                 data["extensions"] = {"style": {
                     "backgroundMediaList": [[100, backgroundImage, None, None, None]]}}
 
-            if isinstance(backgroundImage, BinaryIO):
+            if isinstance(backgroundImage, bytes):
                 image = await self.upload_media(backgroundImage, "image")
                 data["extensions"] = {"style": {"backgroundMediaList": [[100, image, None, None, None]]}}
 
@@ -749,7 +751,7 @@ class Client(AminoHttpClient):
         return response.status
     
     async def set_privacy_status(self, isAnonymous: bool = False, getNotifications: bool = False) -> int:
-        data = {"timestamp": int(time() * 1000)}
+        data = {}
 
         if not isAnonymous: data["privacyMode"] = 1
         if isAnonymous: data["privacyMode"] = 2
@@ -761,7 +763,7 @@ class Client(AminoHttpClient):
         return response.status
 
     async def set_amino_id(self, aminoId: str) -> int:
-        data = {"aminoId": aminoId, "timestamp": int(time() * 1000)}
+        data = {"aminoId": aminoId}
 
         response = await self.post(f"/g/s/account/change-amino-id", data)
         return response.status
@@ -775,7 +777,7 @@ class Client(AminoHttpClient):
         return list(map(lambda o: Community(**o), (await response.json())["unlinkedCommunityList"]))
 
     async def reorder_linked_communities(self, comIds: list) -> int:
-        data = {"ndcIds": comIds, "timestamp": int(time() * 1000)}
+        data = {"ndcIds": comIds}
         response = await self.post(f"/g/s/user-profile/{self.userId}/linked-community/reorder", data)
         return response.status
 
@@ -792,8 +794,7 @@ class Client(AminoHttpClient):
         data = {
             "content": message,
             "stickerId": None,
-            "type": 0,
-            "timestamp": int(time() * 1000)
+            "type": 0
         }
 
         if replyTo:
@@ -833,8 +834,7 @@ class Client(AminoHttpClient):
     
     async def like_blog(self, blogId: Union[str, list] = None, wikiId: str = None) -> int:
         data = {
-            "value": 4,
-            "timestamp": int(time() * 1000)
+            "value": 4
         }
 
         if blogId:
@@ -871,8 +871,7 @@ class Client(AminoHttpClient):
     
     async def like_comment(self, commentId: str, userId: str = None, blogId: str = None, wikiId: str = None) -> int:
         data = {
-            "value": 4,
-            "timestamp": int(time() * 1000)
+            "value": 4
         }
 
         if userId:
@@ -935,8 +934,7 @@ class Client(AminoHttpClient):
         data = {
             "objectId": objectId,
             "targetCode": 1,
-            "objectType": objectType,
-            "timestamp": int(time() * 1000)
+            "objectType": objectType
         }
 
         if comId: url = f"/g/s/link-resolution"
@@ -972,8 +970,7 @@ class Client(AminoHttpClient):
 
     async def wallet_config(self, level: int):
         data = {
-            "adsLevel": level,
-            "timestamp": int(time() * 1000)
+            "adsLevel": level
         }
 
         response = await self.post(f"/g/s/wallet/ads/config", data)
@@ -1003,11 +1000,10 @@ class Client(AminoHttpClient):
     async def change_avatar_frame(self, frameId: str, aplyToAll: bool = False) -> int:
         data = {
             "frameId": frameId,
-            "applyToAll": 1 if aplyToAll else 0,
-            "timestamp": int(time() * 1000)
+            "applyToAll": 1 if aplyToAll else 0
         }
 
-        response = await self.post(f"{self.apip}/g/s/avatar-frame/apply", data)
+        response = await self.post(f"/g/s/avatar-frame/apply", data)
         return response.status
     
     def create_bubble_config(self, allowedSlots: list = None, contentInsets: list = None, coverImage: str = None, id: str = None, name: str = None, previewBackgroundUrl: str = None, slots: list = None,
@@ -1044,7 +1040,7 @@ class Client(AminoHttpClient):
             zipfile.writestr("config.json", bubbleConfig.json())
         return buffer.getvalue()
 
-    def load_bubble(self, bubble_zip: BinaryIO) -> Tuple[bytes, ChatBubble.Config]:
+    def load_bubble(self, bubble_zip: bytes) -> Tuple[bytes, ChatBubble.Config]:
         with ZipFile(io.BytesIO(bubble_zip), 'r') as zipfile:
             config = loads(zipfile.read("config.json"))
 
@@ -1056,29 +1052,28 @@ class Client(AminoHttpClient):
         data = {
             "bubbleId": bubbleId,
             "applyToAll": 0 if chatId else 1,
-            "threadId": chatId if chatId else None,
-            "timestamp": int(time() * 1000)
+            "threadId": chatId if chatId else None
         }
 
-        response = await self.post(f"{self.api}/g/s/chat/thread/apply-bubble", data)
+        response = await self.post(f"/g/s/chat/thread/apply-bubble", data)
         return response.status
     
     async def get_chat_bubbles(self, chatId: str, start: int = 25, size: int = 25) -> List[ChatBubble]:
-        response = await self.get(f"{self.api}/g/s/chat/chat-bubble?type=all-my-bubbles?threadId={chatId}?start={start}?size={size}")
+        response = await self.get(f"/g/s/chat/chat-bubble?type=all-my-bubbles?threadId={chatId}?start={start}?size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["chatBubbleList"]))
     
     async def get_chat_bubble(self, bubbleId: str) -> ChatBubble:
-        response = await self.get(f"{self.api}/g/s/chat/chat-bubble/{bubbleId}")
+        response = await self.get(f"/g/s/chat/chat-bubble/{bubbleId}")
         return ChatBubble(**(response.text)["chatBubble"])
 
     async def get_chat_bubble_templates(self, start: int = 0, size: int = 25) -> List[ChatBubble]:
-        response = await self.get(f"{self.api}/g/s/chat/chat-bubble/templates?start={start}&size={size}")
+        response = await self.get(f"/g/s/chat/chat-bubble/templates?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["templateList"]))
     
-    async def generate_chat_bubble(self, bubble: BinaryIO = None, templateId: str = "949156e1-cc43-49f0-b9cf-3bbbb606ad6e") -> ChatBubble:
-        response = await self.post(f"{self.api}/g/s/chat/chat-bubble/templates/{templateId}/generate", bubble)
+    async def generate_chat_bubble(self, bubble: bytes = None, templateId: str = "949156e1-cc43-49f0-b9cf-3bbbb606ad6e") -> ChatBubble:
+        response = await self.post(f"/g/s/chat/chat-bubble/templates/{templateId}/generate", bubble)
         return ChatBubble(**(response.text)["chatBubble"])
     
-    async def edit_chat_bubble(self, bubbleId: str, bubble: BinaryIO) -> ChatBubble:
-        response = await self.post(f"{self.api}/g/s/chat/chat-bubble/{bubbleId}", bubble)
+    async def edit_chat_bubble(self, bubbleId: str, bubble: bytes) -> ChatBubble:
+        response = await self.post(f"/g/s/chat/chat-bubble/{bubbleId}", bubble)
         return ChatBubble(**(response.text)["chatBubble"])
