@@ -4,19 +4,18 @@ import json
 import os
 
 from time import time
-from typing import Any, Dict, List, Union
+from typing import Dict, List, Union
 from ujson import loads
 from base64 import b64decode, b64encode
-from functools import cache, reduce
+from functools import reduce
 
 PREFIX = bytes.fromhex("42")
 SIG_KEY = bytes.fromhex("F8E7A61AC3F725941E3AC7CAE2D688BE97F30B93")
 DEVICE_KEY = bytes.fromhex("02B258C63559D8804321C5D5065AF320358D366F")
 
 
-@cache
 def generate_device(data: bytes = None) -> str:
-    identifier = b"ED==" + data or os.urandom(16)
+    identifier = b"ED==" + (data or os.urandom(16))
     mac = hmac.new(DEVICE_KEY, PREFIX + identifier, sha1)
     return f"{PREFIX.hex()}{identifier.hex()}{mac.hexdigest()}".upper()
 
@@ -45,7 +44,7 @@ def sid_to_ip_address(sid: str) -> str:
 
 def is_json(myjson) -> bool:
     try:
-        json_object = json.loads(myjson)
-    except ValueError as e:
+        json.loads(myjson)
+    except ValueError:
         return False
     return True
